import * as types from './graphql';
import type { TypedDocumentNode as DocumentNode } from '@graphql-typed-document-node/core';
/**
 * Map of all GraphQL operations in the project.
 *
 * This map has several performance disadvantages:
 * 1. It is not tree-shakeable, so it will include all operations in the project.
 * 2. It is not minifiable, so the string of a GraphQL query will be multiple times inside the bundle.
 * 3. It does not support dead code elimination, so it will add unused operations.
 *
 * Therefore it is highly recommended to use the babel or swc plugin for production.
 */
declare const documents: {
    "\nfragment ContextFields on AnyVersionContextObject {\n  repo {...RepositoryFields}\n  histories {...HistoryFields}\n  deltas {...DeltaFields}\n  storeRoot\n}\n\nfragment RepositoryFields on AnyVersionRepositoryObject {\n  id,\n  filePath,\n  ctime,\n  mtime,\n  lastHistoryId,\n  changes,\n}\n\nfragment HistoryFields on AnyVersionHistoryObject {\n    id,\n  ctime,\n  sigPath,\n  sigSize,\n  repoId,\n  fileSize,\n  fileHash,\n  recovered,\n  recoveryPath,\n  message,\n}\n\nfragment DeltaFields on AnyVersionDeltaObject {\n    id,\n    repoId,\n  fromHistoryId,\n  toHistoryId,\n  deltaForwardPath,\n  deltaBackwardPath,\n  deltaForwardSize,\n  deltaBackwardSize,\n}\n": DocumentNode<types.ContextFieldsFragment, unknown>;
    "\nmutation CreateRepo($input: CreateRepositoryInput!) {\n  createRepository(input: $input) {\n    ...ContextFields\n  }\n}\n": DocumentNode<types.CreateRepoMutation, types.Exact<{
        input: types.CreateRepositoryInput;
    }>>;
    "\nmutation CommitRepo($input: CommitRepositoryInput!) {\n  commitRepository(input: $input) {\n    ...ContextFields\n  }\n}\n": DocumentNode<types.CommitRepoMutation, types.Exact<{
        input: types.CommitRepositoryInput;
    }>>;
    "\nmutation RollbackRepo($input: RollbackRepositoryInput!) {\n  rollbackRepository(input: $input) {\n    ...ContextFields\n  }\n}\n": DocumentNode<types.RollbackRepoMutation, types.Exact<{
        input: types.RollbackRepositoryInput;
    }>>;
    "\nmutation PruneRepo($input: PruneRepositoryInput!) {\n  pruneRepository(input: $input) {\n    ...ContextFields\n  }\n}\n": DocumentNode<types.PruneRepoMutation, types.Exact<{
        input: types.PruneRepositoryInput;
    }>>;
    "\nmutation RecoverRepo($input: RecoverRepositoryInput!) {\n  recoverRepository(input: $input) {\n    ...ContextFields\n  }\n}\n": DocumentNode<types.RecoverRepoMutation, types.Exact<{
        input: types.RecoverRepositoryInput;
    }>>;
    "\nmutation UncoverRepo($input: UncoverRepositoryInput!) {\n  uncoverRepository(input: $input) {\n    ...ContextFields\n  }\n}\n": DocumentNode<types.UncoverRepoMutation, types.Exact<{
        input: types.UncoverRepositoryInput;
    }>>;
    "\nquery QueryAll {\n    getRepositories {\n        id,\n        repoId,\n        filePath,\n        storeRoot,\n        active,\n        changes\n    }\n}\n": DocumentNode<types.QueryAllQuery, types.Exact<{
        [key: string]: never;
    }>>;
    "\nquery QueryRepo($repoId: String!) {\n    getRepositoryByRepoId (\n        repoId: $repoId\n    ) {\n        ...ContextFields\n    }\n}\n": DocumentNode<types.QueryRepoQuery, types.Exact<{
        repoId: string;
    }>>;
};
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 *
 *
 * @example
 * ```ts
 * const query = graphql(`query GetUser($id: ID!) { user(id: $id) { name } }`);
 * ```
 *
 * The query argument is unknown!
 * Please regenerate the types.
 */
export declare function graphql(source: string): unknown;
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nfragment ContextFields on AnyVersionContextObject {\n  repo {...RepositoryFields}\n  histories {...HistoryFields}\n  deltas {...DeltaFields}\n  storeRoot\n}\n\nfragment RepositoryFields on AnyVersionRepositoryObject {\n  id,\n  filePath,\n  ctime,\n  mtime,\n  lastHistoryId,\n  changes,\n}\n\nfragment HistoryFields on AnyVersionHistoryObject {\n    id,\n  ctime,\n  sigPath,\n  sigSize,\n  repoId,\n  fileSize,\n  fileHash,\n  recovered,\n  recoveryPath,\n  message,\n}\n\nfragment DeltaFields on AnyVersionDeltaObject {\n    id,\n    repoId,\n  fromHistoryId,\n  toHistoryId,\n  deltaForwardPath,\n  deltaBackwardPath,\n  deltaForwardSize,\n  deltaBackwardSize,\n}\n"): (typeof documents)["\nfragment ContextFields on AnyVersionContextObject {\n  repo {...RepositoryFields}\n  histories {...HistoryFields}\n  deltas {...DeltaFields}\n  storeRoot\n}\n\nfragment RepositoryFields on AnyVersionRepositoryObject {\n  id,\n  filePath,\n  ctime,\n  mtime,\n  lastHistoryId,\n  changes,\n}\n\nfragment HistoryFields on AnyVersionHistoryObject {\n    id,\n  ctime,\n  sigPath,\n  sigSize,\n  repoId,\n  fileSize,\n  fileHash,\n  recovered,\n  recoveryPath,\n  message,\n}\n\nfragment DeltaFields on AnyVersionDeltaObject {\n    id,\n    repoId,\n  fromHistoryId,\n  toHistoryId,\n  deltaForwardPath,\n  deltaBackwardPath,\n  deltaForwardSize,\n  deltaBackwardSize,\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nmutation CreateRepo($input: CreateRepositoryInput!) {\n  createRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"): (typeof documents)["\nmutation CreateRepo($input: CreateRepositoryInput!) {\n  createRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nmutation CommitRepo($input: CommitRepositoryInput!) {\n  commitRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"): (typeof documents)["\nmutation CommitRepo($input: CommitRepositoryInput!) {\n  commitRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nmutation RollbackRepo($input: RollbackRepositoryInput!) {\n  rollbackRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"): (typeof documents)["\nmutation RollbackRepo($input: RollbackRepositoryInput!) {\n  rollbackRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nmutation PruneRepo($input: PruneRepositoryInput!) {\n  pruneRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"): (typeof documents)["\nmutation PruneRepo($input: PruneRepositoryInput!) {\n  pruneRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nmutation RecoverRepo($input: RecoverRepositoryInput!) {\n  recoverRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"): (typeof documents)["\nmutation RecoverRepo($input: RecoverRepositoryInput!) {\n  recoverRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nmutation UncoverRepo($input: UncoverRepositoryInput!) {\n  uncoverRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"): (typeof documents)["\nmutation UncoverRepo($input: UncoverRepositoryInput!) {\n  uncoverRepository(input: $input) {\n    ...ContextFields\n  }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nquery QueryAll {\n    getRepositories {\n        id,\n        repoId,\n        filePath,\n        storeRoot,\n        active,\n        changes\n    }\n}\n"): (typeof documents)["\nquery QueryAll {\n    getRepositories {\n        id,\n        repoId,\n        filePath,\n        storeRoot,\n        active,\n        changes\n    }\n}\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "\nquery QueryRepo($repoId: String!) {\n    getRepositoryByRepoId (\n        repoId: $repoId\n    ) {\n        ...ContextFields\n    }\n}\n"): (typeof documents)["\nquery QueryRepo($repoId: String!) {\n    getRepositoryByRepoId (\n        repoId: $repoId\n    ) {\n        ...ContextFields\n    }\n}\n"];
export type DocumentType<TDocumentNode extends DocumentNode<any, any>> = TDocumentNode extends DocumentNode<infer TType, any> ? TType : never;
export {};
